@@ -203,6 +203,11 @@ nsMessengerOSXIntegration::nsMessengerOSXIntegration()
 
 nsMessengerOSXIntegration::~nsMessengerOSXIntegration()
 {
+  nsresult rv;
+  nsCOMPtr<nsIObserverService> observerService = do_GetService("@mozilla.org/observer-service;1", &rv);
+  if (NS_SUCCEEDED(rv)) {
+    observerService->RemoveObserver(this, "quit-application");
+  }
   RestoreDockIcon();
 }
 
@@ -226,6 +231,7 @@ nsMessengerOSXIntegration::Init()
   nsCOMPtr<nsIObserverService> observerService = do_GetService("@mozilla.org/observer-service;1", &rv);
   NS_ENSURE_SUCCESS(rv, rv);
   observerService->AddObserver(this, "before-growl-registration", false);
+  observerService->AddObserver(this, "quit-application", false);
   return observerService->AddObserver(this, "mail-startup-done", false);
 }
 
@@ -256,6 +262,15 @@ nsMessengerOSXIntegration::Observe(nsISupports* aSubject, const char* aTopic, co
   if (!strcmp(aTopic, "alertclickcallback"))
     return OnAlertClicked(aData);
 
+  if (!strcmp(aTopic, "quit-application")) {
+    nsresult rv;
+    nsCOMPtr<nsIObserverService> observerService = do_GetService("@mozilla.org/observer-service;1", &rv);
+    if (NS_SUCCEEDED(rv)) {
+      observerService->RemoveObserver(this, "quit-application");
+    }
+    return RestoreDockIcon();
+  }
+
   if (!strcmp(aTopic, "mail-startup-done")) {
     nsresult rv;
     nsCOMPtr<nsIObserverService> observerService = do_GetService("@mozilla.org/observer-service;1", &rv);
