@@ -266,10 +266,10 @@ static bool GMA9XXGraphics()
 {
   bool hasIntelGMA9XX = false;
   CGLRendererInfoObj renderer = 0;
-  GLint rendererCount = 0;
+  long rendererCount = 0;
   if (::CGLQueryRendererInfo(0xffffffff, &renderer, &rendererCount) == kCGLNoError) {
-    for (GLint c = 0; c < rendererCount; c++) {
-      GLint rendProp = 0;
+    for (long c = 0; c < rendererCount; c++) {
+      long rendProp = 0;
       if (::CGLDescribeRenderer(renderer, c, kCGLRPRendererID, &rendProp) == kCGLNoError) {
         if ((rendProp & CGLRendererIDMatchingMask) == CGLRendererIntel900ID) {
           hasIntelGMA9XX = true;
